@@ -6,9 +6,12 @@ from pkg_resources import resource_filename
 import py2app.apptemplate
 from py2app.util import makedirs, mergecopy, mergetree, skipscm, make_exec
 
-def create_appbundle(destdir, name, extension='.app', module=py2app.apptemplate,
+
+def create_appbundle(
+        destdir, name, extension='.app', module=py2app.apptemplate,
         platform='MacOS', copy=mergecopy, mergetree=mergetree,
-        condition=skipscm, plist={}, arch=None):
+        condition=skipscm, plist={}, arch=None, redirect_stdout=False):
+
     kw = module.plist_template.infoPlistDict(
         plist.get('CFBundleExecutable', name), plist)
     app = os.path.join(destdir, kw['CFBundleName'] + extension)
@@ -30,9 +33,11 @@ def create_appbundle(destdir, name, extension='.app', module=py2app.apptemplate,
     for d in dirs:
         makedirs(d)
     plist.write(plistPath)
-    srcmain = module.setup.main(arch=arch)
-    if sys.version_info[0] == 2 and isinstance(kw['CFBundleExecutable'], unicode):
-        destmain = os.path.join(platdir, kw['CFBundleExecutable'].encode('utf-8'))
+    srcmain = module.setup.main(arch=arch, redirect_asl=redirect_stdout)
+    if sys.version_info[0] == 2 \
+            and isinstance(kw['CFBundleExecutable'], unicode):
+        destmain = os.path.join(
+            platdir, kw['CFBundleExecutable'].encode('utf-8'))
     else:
         destmain = os.path.join(platdir, kw['CFBundleExecutable'])
 
@@ -40,6 +45,8 @@ def create_appbundle(destdir, name, extension='.app', module=py2app.apptemplate,
         fp.write(
             kw['CFBundlePackageType'] + kw['CFBundleSignature']
         )
+
+    print("Copy %r -> %r" % (srcmain, destmain))
     copy(srcmain, destmain)
     make_exec(destmain)
     mergetree(
@@ -50,6 +57,6 @@ def create_appbundle(destdir, name, extension='.app', module=py2app.apptemplate,
     )
     return app, plist
 
+
 if __name__ == '__main__':
-    import sys
     create_appbundle('build', sys.argv[1])
