@@ -7,12 +7,19 @@ from pkg_resources import resource_filename
 import py2app.bundletemplate
 from py2app.util import makedirs, mergecopy, mergetree, skipscm, make_exec
 
-def create_pluginbundle(destdir, name, extension='.plugin', module=py2app.bundletemplate,
+
+def create_pluginbundle(
+        destdir, name, extension='.plugin', module=py2app.bundletemplate,
         platform='MacOS', copy=mergecopy, mergetree=mergetree,
         condition=skipscm, plist={}, arch=None):
+
     kw = module.plist_template.infoPlistDict(
         plist.get('CFBundleExecutable', name), plist)
     plugin = os.path.join(destdir, kw['CFBundleName'] + extension)
+    if os.path.exists(plugin):
+        # Remove any existing build artifacts to ensure
+        # we're getting a clean build
+        shutil.rmtree(plugin)
     contents = os.path.join(plugin, 'Contents')
     resources = os.path.join(contents, 'Resources')
     platdir = os.path.join(contents, platform)
@@ -28,8 +35,10 @@ def create_pluginbundle(destdir, name, extension='.plugin', module=py2app.bundle
         makedirs(d)
     plist.write(plistPath)
     srcmain = module.setup.main(arch=arch)
-    if sys.version_info[0] == 2 and isinstance(kw['CFBundleExecutable'], unicode):
-        destmain = os.path.join(platdir, kw['CFBundleExecutable'].encode('utf-8'))
+    if sys.version_info[0] == 2 and \
+            isinstance(kw['CFBundleExecutable'], unicode):
+        destmain = os.path.join(
+            platdir, kw['CFBundleExecutable'].encode('utf-8'))
     else:
         destmain = os.path.join(platdir, kw['CFBundleExecutable'])
     with open(os.path.join(contents, 'PkgInfo'), 'w') as fp:
@@ -46,6 +55,6 @@ def create_pluginbundle(destdir, name, extension='.plugin', module=py2app.bundle
     )
     return plugin, plist
 
+
 if __name__ == '__main__':
-    import sys
     create_pluginbundle('build', sys.argv[1])
