@@ -1,5 +1,6 @@
-from py2app.util import imp_find_module
-import os, sys, glob
+from modulegraph.util import imp_find_module
+import os
+import sys
 
 try:
     from cStringIO import StringIO
@@ -65,8 +66,23 @@ def check(cmd, mf):
     if sip is not None:
         mf.removeReference(sip, 'ImageTk')
 
+    # The ImageQt plugin should only be usefull when using PyQt, which
+    # would then be explicitly imported.
+    # Note: this code doesn't have the right side-effect at the moment
+    # due to the way the PyQt5 recipe is structured.
+    sip = mf.findNode('PIL.ImageQt')
+    if sip is not None:
+        mf.removeReference(sip, 'PyQt5')
+        mf.removeReference(sip, 'PyQt5.QtGui')
+        mf.removeReference(sip, 'PyQt5.QtCore')
+
+        mf.removeReference(sip, 'PyQt4')
+        mf.removeReference(sip, 'PyQt4.QtGui')
+        mf.removeReference(sip, 'PyQt4.QtCore')
+        pass
+
     return dict(
-        prescripts = ['py2app.recipes.PIL.prescript', s],
-        include = "PIL.JpegPresets", # Dodgy import from PIL.JpegPlugin in Pillow 2.0
-        flatpackages = [os.path.dirname(m.filename)],
+        prescripts=['py2app.recipes.PIL.prescript', s],
+        include="PIL.JpegPresets",  # import from PIL.JpegPlugin in Pillow 2.0
+        flatpackages=[os.path.dirname(m.filename)],
     )
