@@ -6,10 +6,14 @@ distutils instead
 This recipe is rather compilicated and definitely not a
 good model for other recipes!!!
 """
-import sys, os, imp
+from __future__ import absolute_import
+import sys
+import os
+import imp
 from modulegraph.modulegraph import MissingModule, \
         Package, SourceModule, CompiledModule, find_module
 
+
 def retry_import(mf, m):
     """
     Try to reimport 'm', which should be a MissingModule
@@ -21,8 +25,6 @@ def retry_import(mf, m):
         parent = None
         partname = m.identifier
 
-
-
     # This is basicly mf.find_module inlined and with a
     # check disabled.
     def fmod(name, path, parent):
@@ -37,9 +39,9 @@ def retry_import(mf, m):
             buf = os.path.realpath(buf)
         return (fp, buf, stuff)
     try:
-        fp, pathname, stuff = fmod(partname,
-                        parent and parent.packagepath, parent)
-    except ImportError as e:
+        fp, pathname, stuff = fmod(
+                partname, parent and parent.packagepath, parent)
+    except ImportError:
         return
 
     if stuff[-1] == imp.PKG_DIRECTORY:
@@ -49,7 +51,13 @@ def retry_import(mf, m):
     else:
         m.__class__ = CompiledModule
 
-    m = mf.load_module(m.identifier, fp, pathname, stuff)
+    # making this match the code later on that checks whether scan_code needs
+    # a leading _
+    if hasattr(mf, 'load_module'):
+        m = mf.load_module(m.identifier, fp, pathname, stuff)
+    else:
+        m = mf._load_module(m.identifier, fp, pathname, stuff)
+
     if parent:
         mf.createReference(m, parent)
         parent[partname] = m
@@ -67,9 +75,10 @@ def check(cmd, mf):
         # This is the virtualenv version
         mos = mf.findNode('os')
         if mos is None or mos.filename is None:
-            raise ValueError("Where is those os module")
+            raise ValueError("Where is the os module")
 
-        m.filename = os.path.join(os.path.dirname(mos.filename), 'distutils', '__init__.py')
+        m.filename = os.path.join(
+            os.path.dirname(mos.filename), 'distutils', '__init__.py')
         with open(m.filename) as fp:
             source = fp.read() + '\n'
         m.code = co = compile(source, m.filename, 'exec')
@@ -96,5 +105,4 @@ def check(cmd, mf):
                     #
                     retry_import(mf, m)
 
-
     return dict()
