@@ -15,6 +15,11 @@ import os
 import signal
 import platform
 import py2app
+from distutils.version import LooseVersion
+if __name__ == "__main__":
+    from tools import kill_child_processes
+else:
+    from .tools import kill_child_processes
 
 DIR_NAME=os.path.dirname(os.path.abspath(__file__))
 
@@ -31,8 +36,11 @@ class TestArgvEmulation (unittest.TestCase):
     # a base-class.
     @classmethod
     def setUpClass(cls):
+        kill_child_processes()
+
         env=os.environ.copy()
         pp = os.path.dirname(os.path.dirname(py2app.__file__))
+        env['TMPDIR'] = os.getcwd()
         if 'PYTHONPATH' in env:
             env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
         else:
@@ -44,7 +52,7 @@ class TestArgvEmulation (unittest.TestCase):
             cwd = cls.app_dir,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
-            close_fds=True,
+            close_fds=False,
             env=env)
         lines = p.communicate()[0]
         if p.wait() != 0:
@@ -59,6 +67,13 @@ class TestArgvEmulation (unittest.TestCase):
         if os.path.exists(os.path.join(cls.app_dir, 'dist')):
             shutil.rmtree(os.path.join(cls.app_dir, 'dist'))
 
+        time.sleep(2)
+
+    def tearDown(self):
+        kill_child_processes()
+        time.sleep(1)
+
+
     #
     # End of setup code
     #
@@ -121,7 +136,7 @@ class TestArgvEmulation (unittest.TestCase):
 
         self.assertEqual(data.strip(), repr([os.path.join(self.app_dir, 'dist/BasicApp.app/Contents/Resources/main.py'), self.open_argument]))
 
-    @unittest.skipIf(platform.mac_ver()[0] < '10.6.', "Test cannot work on OSX 10.5 or earlier")
+    @unittest.skipIf(LooseVersion(platform.mac_ver()[0]) < LooseVersion('10.6'), "Test cannot work on OSX 10.5 or earlier")
     def test_start_with_two_args(self):
         if not self.open_argument.startswith('/'):
             unittest.skip("Only relevant for base class")
@@ -142,6 +157,7 @@ class TestArgvEmulation (unittest.TestCase):
         for x in range(70):     # Argv emulation can take up-to 60 seconds
             time.sleep(1)
             if os.path.exists(path):
+                time.sleep(5)
                 break
 
         self.assertTrue(os.path.isfile(path))
