@@ -31,6 +31,11 @@ import py2app
 import hashlib
 from distutils.sysconfig import get_config_var
 
+if __name__ == "__main__":
+    from tools import kill_child_processes
+else:
+    from .tools import kill_child_processes
+
 DIR_NAME=os.path.dirname(os.path.abspath(__file__))
 
 def make_checksums(path):
@@ -66,8 +71,11 @@ class TestBasicApp (unittest.TestCase):
     # a base-class.
     @classmethod
     def setUpClass(cls):
+        kill_child_processes()
+
         env=os.environ.copy()
         pp = os.path.dirname(os.path.dirname(py2app.__file__))
+        env['TMPDIR'] = os.getcwd()
         if 'PYTHONPATH' in env:
             env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
         else:
@@ -83,7 +91,7 @@ class TestBasicApp (unittest.TestCase):
             cwd = cls.app_dir,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
-            close_fds=True,
+            close_fds=False,
             env=env
             )
         lines = p.communicate()[0]
@@ -107,6 +115,13 @@ class TestBasicApp (unittest.TestCase):
         if os.path.exists(os.path.join(cls.app_dir, 'dist')):
             shutil.rmtree(os.path.join(cls.app_dir, 'dist'))
 
+        time.sleep(2)
+
+    def tearDown(self):
+        kill_child_processes()
+        time.sleep(1)
+
+
     def start_app(self):
         # Start the test app, return a subprocess object where
         # stdin and stdout are connected to pipes.
@@ -117,7 +132,7 @@ class TestBasicApp (unittest.TestCase):
         p = subprocess.Popen([path],
                 stdin=subprocess.PIPE,
                 stdout=subprocess.PIPE,
-                close_fds=True,
+                close_fds=False,
                 )
                 #stderr=subprocess.STDOUT)
         return p
@@ -204,6 +219,8 @@ class TestBasicApp (unittest.TestCase):
 
         p.stdin.close()
         p.stdout.close()
+        exit = self.wait_with_timeout(p)
+        self.assertEqual(exit, 0)
         self.assertChecksumsSame()
 
     def test_is_optimized(self):
@@ -218,6 +235,9 @@ class TestBasicApp (unittest.TestCase):
         finally:
             p.stdin.close()
             p.stdout.close()
+            exit = self.wait_with_timeout(p)
+            self.assertEqual(exit, 0)
+
         self.assertChecksumsSame()
 
 
@@ -237,6 +257,33 @@ class TestBasicApp (unittest.TestCase):
         self.assertEqual(os.readlink(os.path.join(path, fwk)), os.path.join('Versions', 'Current', fwk))
         self.assertEqual(os.readlink(os.path.join(path, 'Resources')), os.path.join('Versions', 'Current', 'Resources'))
 
+    def test_python_executable_mode(self):
+        path = os.path.join(
+                self.app_dir,
+                'dist/BasicApp.app/Contents/MacOS/python')
+
+        self.assertTrue(os.path.exists(path))
+        mode = os.stat(path).st_mode
+        self.assertTrue(mode & 0o001, 'Not executable for other')
+        self.assertTrue(mode & 0o010, 'Not executable for group')
+        self.assertTrue(mode & 0o100, 'Not executable for user')
+
+    def test_python_executable_use(self):
+        p = self.start_app()
+
+        try:
+            p.stdin.write('run_python()\n'.encode('latin1'))
+            p.stdin.flush()
+            ln = p.stdout.readline()
+            self.assertEqual(ln.strip(), b"ok")
+
+        finally:
+            p.stdin.close()
+            p.stdout.close()
+            exit = self.wait_with_timeout(p)
+            self.assertEqual(exit, 0)
+
+
 class TestBasicAliasApp (TestBasicApp):
     py2app_args = [ '--alias', ]
 
@@ -333,6 +380,12 @@ class TestBasicAppUnicodePath (TestBasicApp):
         if os.path.exists(cls.app_dir):
             shutil.rmtree(cls.app_dir)
 
+
+    @unittest.expectedFailure
+    def test_python_executable_use(self):
+        self.fail('loading codecs fails on py36i')
+
+
 class TestBasicAliasAppUnicodePath (TestBasicAppUnicodePath):
     py2app_args = [ '--alias', ]
 
